@@ -42,7 +42,6 @@ the usual way.
 )]
 pub struct Command {
     #[clap(
-        short,
         long = "server",
         default_values_t = DEFAULT_KEYSERVERS.iter().map(ToString::to_string),
         value_name = "URI",
@@ -53,14 +52,13 @@ pub struct Command {
     #[clap(
         help = FileOrCertStore::HELP_OPTIONAL,
         long,
-        short,
         value_name = FileOrCertStore::VALUE_NAME,
     )]
     pub output: Option<FileOrStdout>,
 
     #[clap(
-        short = 'B',
         long,
+        requires = "output",
         help = "Emit binary data",
     )]
     pub binary: bool,
