@@ -47,7 +47,7 @@ fn update_cert_revocation(sq: &Sq,
     let pk = ka.key();
 
     // Derive a signer.
-    let (mut signer, _password) = sq.get_signer(&ka)?;
+    let mut signer = sq.get_signer(&ka)?;
 
     let sig = SignatureBuilder::from(rev.clone())
         .set_signature_creation_time(reference_time.clone())?
@@ -75,7 +75,7 @@ fn update_user_id_binding(sq: &Sq,
     let pk = ka.key();
 
     // Derive a signer.
-    let (mut signer, _password) = sq.get_signer(&ka)?;
+    let mut signer = sq.get_signer(&ka)?;
 
     let sym = &[
         SymmetricAlgorithm::AES128,
@@ -89,7 +89,7 @@ fn update_user_id_binding(sq: &Sq,
 
     // Update the signature.
     let sig = ua.binding_signature();
-    let mut sig = SignatureBuilder::from(sig.clone())
+    let sig = SignatureBuilder::from(sig.clone())
         .set_signature_creation_time(reference_time.clone())?
         .set_hash_algo(GOOD_HASHES[0])
         .set_preferred_hash_algorithms(
@@ -143,7 +143,7 @@ fn update_subkey_binding<P>(sq: &Sq,
     let pk = primary.key();
 
     // Derive a signer.
-    let (mut signer, _password) = sq.get_signer(&primary)?;
+    let mut signer = sq.get_signer(&primary)?;
 
     // Update the signature.
     let sig = ka.binding_signature();
@@ -161,7 +161,7 @@ fn update_subkey_binding<P>(sq: &Sq,
         .nth(0)
     {
         // Derive a signer.
-        let (mut subkey_signer, _password) = sq.get_signer(&ka)?;
+        let mut subkey_signer = sq.get_signer(&ka)?;
 
         let backsig = SignatureBuilder::from(backsig.clone())
             .set_signature_creation_time(reference_time.clone())?
@@ -170,7 +170,7 @@ fn update_subkey_binding<P>(sq: &Sq,
         builder = builder.set_embedded_signature(backsig)?;
     }
 
-    let mut sig = builder.sign_subkey_binding(&mut signer, pk, ka.key())?;
+    let sig = builder.sign_subkey_binding(&mut signer, pk, ka.key())?;
 
     // Verify it.
     assert!(sig.verify_subkey_binding(signer.public(), pk, ka.key())
