@@ -1,5 +1,6 @@
 use std::fs::metadata;
 use std::io;
+use std::path::PathBuf;
 use std::time::SystemTime;
 
 use anyhow::anyhow;
@@ -73,6 +74,7 @@ pub fn dispatch(sq: Sq, command: cli::encrypt::Command) -> Result<()> {
         command.input,
         output,
         command.symmetric as usize,
+        command.symmetric_password_file,
         &recipients,
         additional_secrets,
         signer_keys,
@@ -93,6 +95,7 @@ pub fn encrypt<'a, 'b: 'a>(
     input: FileOrStdin,
     message: Message<'a>,
     npasswords: usize,
+    password_files: Vec<PathBuf>,
     recipients: &'b [openpgp::Cert],
     signers: Vec<openpgp::Cert>,
     signer_keys: &[KeyHandle],
@@ -108,18 +111,24 @@ pub fn encrypt<'a, 'b: 'a>(
     let mut passwords: Vec<crypto::Password> = Vec::with_capacity(npasswords);
     for n in 0..npasswords {
         let nprompt;
-        if let Some(password) = password::prompt_for_new(
+        let password = password::prompt_for_new(
+            sq,
             if npasswords > 1 {
                 nprompt = format!("message (password {})", n + 1);
                 &nprompt
             } else {
                 "message"
             },
-        )? {
-            passwords.push(password)
-        } else {
-            return Err(anyhow::anyhow!("Password can not be empty!"));
-        }
+        )?;
+        passwords.push(password);
+    }
+
+    for password_file in password_files {
+        let password = std::fs::read(&password_file)
+            .with_context(|| {
+                format!("Reading {}", password_file.display())
+            })?;
+        passwords.push(password.into());
     }
 
     if recipients.len() + passwords.len() == 0 {
@@ -145,7 +154,7 @@ pub fn encrypt<'a, 'b: 'a>(
                         "{} is not present on keystore", kh)),
                     1 => (),
                     n => {
-                        eprintln!("Warning: {} is present on multiple \
+                        wprintln!("Warning: {} is present on multiple \
                                    ({}) devices",
                                   kh, n);
                     }
@@ -168,7 +177,7 @@ pub fn encrypt<'a, 'b: 'a>(
                         let keyid = KeyID::from(&fpr);
 
                         if let Some(msg) = msg {
-                            eprintln!("{}", msg);
+                            wprintln!("{}", msg);
                         }
                         loop {
                             let password = Password::from(rpassword::prompt_password(
@@ -191,11 +200,12 @@ pub fn encrypt<'a, 'b: 'a>(
                         | Ok(Protection::ExternalOther(msg)) =>
                     {
                         // Locked.
-                        eprint!("Key is locked");
-                        if let Some(msg) = msg {
-                            eprint!(": {}", msg);
-                        }
-                        eprintln!();
+                        wprintln!("Key is locked{}",
+                                  if let Some(msg) = msg {
+                                      format!(": {}", msg)
+                                  } else {
+                                      "".into()
+                                  });
                     }
                     Err(err) => {
                         // Failed to get the key's locked status.  Just print
@@ -275,7 +285,7 @@ pub fn encrypt<'a, 'b: 'a>(
     // Optionally sign message.
     if ! signers.is_empty() || ! signer_keys.is_empty() {
         let mut signer = if ! signers.is_empty() {
-            Signer::new(sink, signers.pop().unwrap().0)
+            Signer::new(sink, signers.pop().unwrap())
         } else {
             Signer::new(sink, signer_keys.pop().unwrap())
         };
@@ -283,7 +293,7 @@ pub fn encrypt<'a, 'b: 'a>(
             signer = signer.creation_time(time);
         }
         for s in signers {
-            signer = signer.add_signer(s.0);
+            signer = signer.add_signer(s);
         }
         for s in signer_keys {
             signer = signer.add_signer(s);
