@@ -2,7 +2,7 @@
 
 use crate::Sq;
 use crate::cli;
-use crate::common::expire;
+use crate::common::key::expire;
 use crate::Result;
 
 pub fn dispatch(sq: Sq, command: cli::key::expire::Command)
