@@ -1,3 +1,5 @@
+use anyhow::Context;
+
 use chrono::DateTime;
 use chrono::Utc;
 
@@ -18,12 +20,18 @@ use openpgp::Result;
 use crate::Sq;
 use crate::cli::key::SubkeyAddCommand;
 use crate::cli::key::SubkeyCommand;
+use crate::cli::key::SubkeyDeleteCommand;
 use crate::cli::key::SubkeyExpireCommand;
+use crate::cli::key::SubkeyExportCommand;
+use crate::cli::key::SubkeyPasswordCommand;
 use crate::cli::key::SubkeyRevokeCommand;
 use crate::cli::types::EncryptPurpose;
 use crate::cli::types::FileOrStdout;
 use crate::common;
-use crate::common::expire;
+use crate::common::key::expire;
+use crate::common::key::export;
+use crate::common::key::delete;
+use crate::common::key::password;
 use crate::common::NULL_POLICY;
 use crate::common::RevocationOutput;
 use crate::common::get_secret_signer;
@@ -32,6 +40,9 @@ use crate::parse_notations;
 pub fn dispatch(sq: Sq, command: SubkeyCommand) -> Result<()> {
     match command {
         SubkeyCommand::Add(c) => subkey_add(sq, c)?,
+        SubkeyCommand::Export(c) => subkey_export(sq, c)?,
+        SubkeyCommand::Delete(c) => subkey_delete(sq, c)?,
+        SubkeyCommand::Password(c) => subkey_password(sq, c)?,
         SubkeyCommand::Expire(c) => subkey_expire(sq, c)?,
         SubkeyCommand::Revoke(c) => subkey_revoke(sq, c)?,
     }
@@ -39,6 +50,50 @@ pub fn dispatch(sq: Sq, command: SubkeyCommand) -> Result<()> {
     Ok(())
 }
 
+fn subkey_export(sq: Sq, command: SubkeyExportCommand)
+    -> Result<()>
+{
+    assert!(! command.key.is_empty());
+
+    export(sq, vec![], command.key)
+}
+
+fn subkey_delete(sq: Sq, command: SubkeyDeleteCommand)
+    -> Result<()>
+{
+    let handle = if let Some(file) = command.cert_file {
+        assert!(command.cert.is_none());
+        file.into()
+    } else if let Some(kh) = command.cert {
+        kh.into()
+    } else {
+        panic!("clap enforces --cert or --cert-file is set");
+    };
+
+    assert!(! command.key.is_empty());
+
+    delete(sq, handle, command.key, command.output, command.binary)
+}
+
+fn subkey_password(sq: Sq, command: SubkeyPasswordCommand)
+    -> Result<()>
+{
+    let handle = if let Some(file) = command.cert_file {
+        assert!(command.cert.is_none());
+        file.into()
+    } else if let Some(kh) = command.cert {
+        kh.into()
+    } else {
+        panic!("clap enforces --cert or --cert-file is set");
+    };
+
+    assert!(! command.key.is_empty());
+
+    password(sq, handle, command.key,
+             command.clear_password, command.new_password_file.as_deref(),
+             command.output, command.binary)
+}
+
 fn subkey_expire(sq: Sq, command: SubkeyExpireCommand)
     -> Result<()>
 {
@@ -215,15 +270,19 @@ fn subkey_add(
     // If a password is needed to use the key, the user will be prompted.
     let (primary_key, password) =
         match sq.get_primary_key(&cert, None) {
-            Ok((key, password)) => {
-                // provide a password or reuse that of the primary key
-                if command.with_password {
-                    (
-                        key,
-                        common::password::prompt_for_new("subkey")?,
-                    )
+            Ok(key) => {
+                // Don't use a password, or prompt for one.
+                if let Some(password_file) = command.new_password_file {
+                    let password = std::fs::read(&password_file)
+                        .with_context(|| {
+                            format!("Reading {}", password_file.display())
+                        })?;
+                    (key, Some(password.into()))
+                } else if command.without_password {
+                    (key, None)
                 } else {
-                    (key, password)
+                    (key, common::password::prompt_for_new_or_none(
+                        &sq, "subkey")?)
                 }
             }
             Err(error) => {
