@@ -6,11 +6,6 @@ use sequoia_openpgp as openpgp;
 use sequoia_wot as wot;
 use wot::Path;
 
-#[cfg(feature = "dot-writer")]
-mod dot;
-#[cfg(feature = "dot-writer")]
-pub use dot::DotOutputNetwork;
-
 mod human_readable;
 pub use human_readable::print_path;
 pub use human_readable::print_path_error;
