@@ -13,9 +13,8 @@ pub mod sanitize;
 pub mod wrapping;
 
 pub use keyring::ListItem as KeyringListItem;
-pub use wkd::WkdUrlVariant;
 
-use crate::cli::output::{OutputFormat, OutputVersion};
+use crate::cli::output::OutputVersion;
 
 pub const DEFAULT_OUTPUT_VERSION: OutputVersion = OutputVersion::new(0, 0, 0);
 pub const OUTPUT_VERSIONS: &[OutputVersion] = &[OutputVersion::new(0, 0, 0)];
@@ -30,7 +29,6 @@ pub const OUTPUT_VERSIONS: &[OutputVersion] = &[OutputVersion::new(0, 0, 0)];
 /// Each variant is created by a dedicated function.
 pub enum Model {
     KeyringListV0(keyring::ListV0),
-    WkdUrlV0(wkd::UrlV0),
 }
 
 impl Model {
@@ -39,24 +37,10 @@ impl Model {
         v.unwrap_or(DEFAULT_OUTPUT_VERSION)
     }
 
-    /// Create a model for the output of `sq wkd url` and `sq wkd
-    /// direct-url` subcommands.
-    pub fn wkd_url(version: Option<OutputVersion>,
-                   variant: wkd::WkdUrlVariant,
-                   advanced_url: String,
-                   direct_url: String) -> Result<Self> {
-        let version = Self::version(version);
-        let result = match version {
-            wkd::UrlV0::V => Self::WkdUrlV0(wkd::UrlV0::new(variant, advanced_url, direct_url)),
-            _ => return Err(anyhow!("unknown output version {:?}", version)),
-        };
-        Ok(result)
-    }
-
     /// Create a model for the output of the `sq toolbox keyring list`
     /// subcommand.
-    pub fn keyring_list(version: Option<OutputVersion>, certs: Vec<keyring::ListItem>, all_uids: bool) -> Result<Self> {
-        let version = Self::version(version);
+    pub fn keyring_list(certs: Vec<keyring::ListItem>, all_uids: bool) -> Result<Self> {
+        let version = Self::version(None);
         let result = match version {
             keyring::ListV0::V => Self::KeyringListV0(keyring::ListV0::new(certs, all_uids)),
             _ => return Err(anyhow!("unknown output version {:?}", version)),
@@ -66,38 +50,14 @@ impl Model {
 
     /// Write the output of a model to an open write handle in the
     /// format requested by the user.
-    pub fn write(&self, format: OutputFormat, w: &mut dyn Write) -> Result<()> {
+    pub fn write(&self, w: &mut dyn Write) -> Result<()> {
         match self {
-            Self::KeyringListV0(x) => {
-                match format {
-                    OutputFormat::Json => x.json(w)?,
-                    _ => x.human_readable(w)?,
-                }
-            }
-            Self::WkdUrlV0(x) => {
-                match format {
-                    OutputFormat::Json => x.json(w)?,
-                    _ => x.human_readable(w)?,
-                }
-            }
+            Self::KeyringListV0(x) => x.human_readable(w)?
         }
         Ok(())
     }
 }
 
-/// Serializes an object to JSON.
-pub fn to_json<O, W>(mut w: W, o: &O) -> Result<()>
-where
-    O: serde::Serialize,
-    W: std::io::Write,
-{
-    // Pretty-print, then add a final newline.
-    serde_json::to_writer_pretty(&mut w, o)?;
-    writeln!(w)?;
-    Ok(())
-}
-
-
 // Model output as a data type that can be serialized.
 mod keyring {
     use sequoia_openpgp as openpgp;
@@ -152,10 +112,6 @@ mod keyring {
             }
             Ok(())
         }
-
-        pub fn json(&self, w: &mut dyn Write) -> Result<()> {
-            super::to_json(w, self)
-        }
     }
 
     #[derive(Debug, Serialize)]
@@ -237,49 +193,3 @@ mod keyring {
         }
     }
 }
-
-// Model output as a data type that can be serialized.
-pub mod wkd {
-    use super::{OutputVersion, Result, Write};
-    use serde::Serialize;
-
-    #[derive(Debug)]
-    pub enum WkdUrlVariant {
-        Advanced,
-        Direct,
-    }
-
-    #[derive(Debug, Serialize)]
-    pub struct UrlV0 {
-        #[serde(skip)]
-        variant: WkdUrlVariant,
-        sq_output_version: OutputVersion,
-        advanced_url: String,
-        direct_url: String,
-    }
-
-    impl UrlV0 {
-        pub const V: OutputVersion = OutputVersion::new(0, 0, 0);
-
-        pub fn new(variant: WkdUrlVariant, advanced_url: String, direct_url: String) -> Self {
-            Self {
-                sq_output_version: Self::V,
-                variant,
-                advanced_url,
-                direct_url,
-            }
-        }
-
-        pub fn human_readable(&self, w: &mut dyn Write) -> Result<()> {
-            match self.variant {
-                WkdUrlVariant::Advanced => writeln!(w, "{}", self.advanced_url)?,
-                WkdUrlVariant::Direct => writeln!(w, "{}", self.direct_url)?,
-            }
-            Ok(())
-        }
-
-        pub fn json(&self, w: &mut dyn Write) -> Result<()> {
-            super::to_json(w, self)
-        }
-    }
-}
